@@ -1,7 +1,11 @@
-#!/usr/bin/perl -w
+#!/usr/bin/perl
+
 # channel_info.pl
 # print channel info
+
 use strict;
+use warnings;
+
 use XML::RSS;
 
 my $rss = new XML::RSS;
